@@ -53,7 +53,8 @@
 #'
 #'   \itemize{
 #'     \item summ.lm = `c(N = "nobs", R2 = "r.squared")`,
-#'     \item summ.glm = `c(N = "nobs", AIC = "AIC", BIC = "BIC")`,
+#'     \item summ.glm = \code{c(N = "nobs", AIC = "AIC", BIC = "BIC",
+#'                        `Pseudo R2` = "pseudo.r.squared")},
 #'     \item summ.svyglm = `c(N = "nobs", R2 = "r.squared")`,
 #'     \item summ.merMod = \code{c(N = "nobs", AIC = "AIC", BIC = "BIC",
 #'                           `R2 (fixed)` = "r.squared.fixed",
@@ -237,7 +238,8 @@ export_summs <- function(...,
       # If a summ object, get its default statistics
       statistics <- switch(mod_type,
              summ.lm = c(N = "nobs", R2 = "r.squared"),
-             summ.glm = c(N = "nobs", AIC = "AIC", BIC = "BIC"),
+             summ.glm = c(N = "nobs", AIC = "AIC", BIC = "BIC",
+                          `Pseudo R2` = "pseudo.r.squared"),
              summ.svyglm = c(N = "nobs", R2 = "r.squared"),
              summ.rq = c(N = "nobs", tau = "tau", R1 = "r.1",
                          AIC = "AIC", BIC = "BIC"),
@@ -393,6 +395,15 @@ export_summs <- function(...,
 #' @param legend.title What should the title for the legend be? Default is
 #'   "Model", but you can specify it here since it is rather difficult to
 #'   change later via `ggplot2`'s typical methods.
+#' @param groups If you would like to have facets (i.e., separate panes) for
+#'   different groups of coefficients, you can specifiy those groups with a
+#'   list here. See details for more on how to do this.
+#' @param facet.rows The number of rows in the facet grid (the `nrow` argument
+#'   to [ggplot2::facet_wrap()]).
+#' @param facet.cols The number of columns in the facet grid (the `nrow`
+#'   argument to [ggplot2::facet_wrap()]).
+#' @param facet.label.pos Where to put the facet labels. One of "top" (the
+#'   default), "bottom", "left", or "right".
 #' @return A ggplot object.
 #' @details A note on the distinction between `plot_summs` and `plot_coefs`:
 #'   `plot_summs` only accepts models supported by [summ()] and allows users
@@ -410,6 +421,13 @@ export_summs <- function(...,
 #'   the argument like this:
 #'   \code{c("Horsepower" = "hp", "Miles/gallon" = "mpg")}
 #'
+#'   To use the `groups` argument, provide a (preferably named) list of
+#'   character vectors. If I want separate panes with "Frost" and "Illiteracy"
+#'   in one and "Population" and "Area" in the other, I'd make a list like
+#'   this:
+#'
+#'   `list(pane_1 = c("Frost", "Illiteracy"), pane_2 = c("Population", "Area"))`
+#'
 #' @examples
 #' states <- as.data.frame(state.x77)
 #' fit1 <- lm(Income ~ Frost + Illiteracy + Murder +
@@ -438,7 +456,9 @@ plot_summs <- function(..., ci_level = .95, model.names = NULL, coefs = NULL,
                        omit.coefs = "(Intercept)", inner_ci_level = NULL,
                        color.class = "CUD Bright", plot.distributions = FALSE,
                        rescale.distributions = FALSE, exp = FALSE,
-                       point.shape = TRUE, legend.title = "Model") {
+                       point.shape = TRUE, legend.title = "Model",
+                       groups = NULL, facet.rows = NULL, facet.cols = NULL,
+                       facet.label.pos = "top") {
 
   # Capture arguments
   dots <- list(...)
@@ -464,7 +484,9 @@ plot_summs <- function(..., ci_level = .95, model.names = NULL, coefs = NULL,
             inner_ci_level = inner_ci_level, color.class = list(color.class),
             plot.distributions = plot.distributions,
             rescale.distributions = rescale.distributions, exp = exp,
-            point.shape = point.shape, legend.title = legend.title, ex_args))
+            point.shape = point.shape, legend.title = legend.title,
+            groups = groups, facet.rows = facet.rows, facet.cols = facet.cols,
+            facet.label.pos = facet.label.pos, ex_args))
 
   do.call("plot_coefs", args = args)
 
@@ -481,7 +503,9 @@ plot_coefs <- function(..., ci_level = .95, inner_ci_level = NULL,
                        color.class = "CUD Bright", plot.distributions = FALSE,
                        rescale.distributions = FALSE,
                        exp = FALSE, point.shape = TRUE,
-                       legend.title = "Model") {
+                       legend.title = "Model", groups = NULL,
+                       facet.rows = NULL, facet.cols = NULL,
+                       facet.label.pos = "top") {
 
   if (!requireNamespace("broom", quietly = TRUE)) {
     stop_wrap("Install the broom package to use the plot_coefs function.")
@@ -559,8 +583,31 @@ plot_coefs <- function(..., ci_level = .95, inner_ci_level = NULL,
     tidies[exp_cols] <- exp(tidies[exp_cols])
   }
 
+  # Put a factor in the model for facetting purposes
+  if (!is.null(groups)) {
+    tidies$group <- NA
+    for (g in seq_len(length(groups))) {
+      if (is.null(names(groups)) || names(groups)[g] == "") {
+        tidies$group[tidies$term %in% groups[[g]]] <- as.character(g)
+      } else {
+        tidies$group[tidies$term %in% groups[[g]]] <- names(groups)[g]
+      }
+    }
+    if (plot.distributions == TRUE) {
+      warn_wrap("Distributions cannot be plotted when groups are used.")
+    }
+  }
+
   p <- ggplot(data = tidies)
 
+  if (!is.null(groups)) {
+    if (is.null(facet.rows) & is.null(facet.cols)) {
+      facet.cols <- 1
+    }
+    p <- p + facet_wrap(group ~ ., nrow = facet.rows, ncol = facet.cols,
+                        scales = "free_y", strip.position = facet.label.pos)
+  }
+
   # Checking if user provided the colors his/herself
   if (length(color.class) == 1 | length(color.class) != n_models) {
     colors <- get_colors(color.class, n_models)
@@ -628,12 +675,11 @@ plot_coefs <- function(..., ci_level = .95, inner_ci_level = NULL,
      breaks = rev(levels(tidies$model)),
      labels = rev(levels(tidies$model)),
      name = legend.title) +
-    scale_y_discrete(limits = rev(levels(tidies$term)),
-                     name = legend.title) +
     scale_shape_manual(limits = rev(levels(tidies$model)),
       values = shapes, name = legend.title) +
     theme_apa(legend.pos = "right", legend.font.size = 9,
-              remove.x.gridlines = FALSE, legend.use.title = TRUE) +
+              remove.x.gridlines = FALSE, legend.use.title = TRUE,
+              facet.title.size = 10) +
     theme(axis.title.y = element_blank(),
           axis.text.y = element_text(size = 10)) +
     xlab(ifelse(exp, no = "Estimate", yes = "exp(Estimate)"))
@@ -641,8 +687,16 @@ plot_coefs <- function(..., ci_level = .95, inner_ci_level = NULL,
   # Plotting distributions often causes distributions to poke out above top
   # of plotting area so I need to set manually
   if (plot.distributions == TRUE) {
-    yrange <- ggplot_build(p)$layout$panel_ranges[[1]]$y.range
-    xrange <- ggplot_build(p)$layout$panel_ranges[[1]]$x.range
+
+    p <- p + scale_y_discrete(limits = rev(levels(tidies$term)),
+                          name = legend.title)
+
+    yrange <- ggplot_build(p)$layout$panel_params[[1]]$y.range
+    xrange <- ggplot_build(p)$layout$panel_params[[1]]$x.range
+    if (is.null(yrange) & is.null(xrange)) { # ggplot 2.2.x compatibility
+      yrange <- ggplot_build(p)$layout$panel_ranges[[1]]$y.range
+      xrange <- ggplot_build(p)$layout$panel_ranges[[1]]$x.range
+    }
 
     if (yrange[2] <= (length(unique(tidies$term)) + 0.8)) {
       upper_y <- length(unique(tidies$term)) + 0.8
@@ -667,8 +721,10 @@ make_tidies <- function(mods, ex_args, ci_level, model.names, omit.coefs,
     if (!is.null(ex_args)) {
 
       method_stub <- find_S3_class("tidy", mods[[i]], package = "broom")
-      method_args <-
-        formals(getS3method("tidy", method_stub, envir = getNamespace("broom")))
+      # getS3method() only available in R >= 3.3
+      the_method <- get(paste0("tidy.", method_stub), asNamespace("broom"),
+                        mode = "function")
+      method_args <- formals(the_method)
 
       method_args <-
         method_args[names(method_args) %nin% c("intervals", "prob")]
@@ -730,7 +786,8 @@ make_tidies <- function(mods, ex_args, ci_level, model.names, omit.coefs,
   # only line up when they are reversed here and in the limits arg of
   # scale_colour_brewer...no clue why that has to be the case
   tidies$model <- factor(tidies$model, levels = rev(model.names))
-  tidies$term <- factor(tidies$term, levels = coefs, labels = names(coefs))
+  tidies$term <- factor(tidies$term, levels = rev(coefs),
+                        labels = rev(names(coefs)))
 
   if (all(c("upper", "lower") %in% names(tidies)) &
       "conf.high" %nin% names(tidies)) {
@@ -812,8 +869,11 @@ get_dist_curves <- function(tidies, order, models, rescale.distributions) {
 tidy.summ <- function(x, conf.int = FALSE, conf.level = .95, ...) {
 
   if (class(x)[1] != "summ.rq") {
-    base <- broom::tidy(x$model, conf.int = conf.int, conf.level = conf.level,
-                        ...)
+    # Hacky fix for spurious broom warnings with merMod
+    suppressWarnings({
+      base <- broom::tidy(x$model, conf.int = conf.int, conf.level = conf.level,
+                          ...)
+    })
   } else {
     dots <- list(...)
     dots <- dots[names(dots) %in% c(names(formals("rq")),
@@ -845,11 +905,11 @@ tidy.summ <- function(x, conf.int = FALSE, conf.level = .95, ...) {
 
   if ("p" %in% colnames(x$coeftable)) {
 
-    base$p.value[!is.na(base$statistic)] <- x$coeftable[,"p"]
+    base[["p.value"]][!is.na(base$statistic)] <- x$coeftable[,"p"]
 
   } else if (!("p.value" %in% names(base))) {
 
-    base$p.value <- NA
+    base[["p.value"]] <- NA
 
   }
 
@@ -941,6 +1001,8 @@ glance.summ.lm <- function(x, ...) {
 glance.summ.glm <- function(x, ...) {
 
   base <- broom::glance(x$model)
+  base["pseudo.r.squared"] <- attr(x, "rsq")
+  base["pseudo.r.squared.mcfadden"] <- attr(x, "rsqmc")
   return(base)
 
 }
@@ -975,6 +1037,8 @@ glance.summ.svyglm <- function(x, ...) {
   } else {
 
     base$r.squared <- NA
+    base["pseudo.r.squared"] <- attr(x, "rsq")
+    base["pseudo.r.squared.mcfadden"] <- attr(x, "rsqmc")
 
   }
 
