@@ -164,6 +164,26 @@ test_that("interact_plot linearity.check works", {
   expect_silent(print(p))
 })
 
+if (requireNamespace("huxtable") && requireNamespace("broom")) {
+  test_that("as_huxtable.sim_slopes works", {
+    ss3 <- sim_slopes(model = fit, pred = Murder, modx = Illiteracy,
+                      mod2 = HSGrad)
+    ss <- sim_slopes(model = fit, pred = Murder, modx = Illiteracy)
+    expect_is(as_huxtable.sim_slopes(ss3), "huxtable")
+    expect_is(as_huxtable.sim_slopes(ss), "huxtable")
+  })
+}
+
+if (requireNamespace("ggstance") && requireNamespace("broom")) {
+  test_that("plot.sim_slopes works", {
+    ss3 <- sim_slopes(model = fit, pred = Murder, modx = Illiteracy,
+                      mod2 = HSGrad)
+    ss <- sim_slopes(model = fit, pred = Murder, modx = Illiteracy)
+    expect_is(plot(ss3), "ggplot")
+    expect_is(plot(ss), "ggplot")
+  })
+}
+
 context("interactions svyglm")
 
 if (requireNamespace("survey")) {
@@ -378,6 +398,21 @@ test_that("johnson_neyman control.fdr argument works", {
                                  control.fdr = TRUE), "johnson_neyman")
 })
 
+test_that("johnson_neyman critical.t argument works", {
+  expect_s3_class(johnson_neyman(fit, pred = Murder, modx = Illiteracy,
+                                 critical.t = 2.1), "johnson_neyman")
+})
+
+test_that("johnson_neyman color arguments work", {
+  expect_silent(johnson_neyman(fit, pred = Murder, modx = Illiteracy,
+                               sig.color = "black", insig.color = "grey")$plot)
+})
+
+test_that("johnson_neyman mod.range argument works", {
+  expect_silent(johnson_neyman(fit, pred = Murder, modx = Illiteracy,
+                               mod.range = c(1, 2))$plot)
+})
+
 ### cat_plot ##################################################################
 
 context("cat_plot")
